@@ -32,7 +32,7 @@ imports.gi.versions.Tracker = '1.0';
 imports.gi.versions.TrackerControl = '1.0';
 imports.gi.versions.EvinceDocument = '3.0';
 imports.gi.versions.Goa = '1.0';
-imports.gi.versions.WebKit = '3.0';
+imports.gi.versions.WebKit2 = '4.0';
 
 const EvDoc = imports.gi.EvinceDocument;
 const GdPrivate = imports.gi.GdPrivate;
@@ -110,17 +110,27 @@ const Application = new Lang.Class({
     Name: 'Application',
     Extends: Gtk.Application,
 
-    _init: function() {
+    _init: function(isBooks) {
         this.minersRunning = [];
         this._activationTimestamp = Gdk.CURRENT_TIME;
         this._extractPriority = null;
 
+        this.isBooks = isBooks;
+
         Gettext.bindtextdomain('gnome-documents', Path.LOCALE_DIR);
         Gettext.textdomain('gnome-documents');
-        GLib.set_prgname('gnome-documents');
-        GLib.set_application_name(_("Documents"));
+        let appid;
+        if (!this.isBooks) {
+            GLib.set_prgname('gnome-documents');
+            GLib.set_application_name(_("Documents"));
+            appid = 'org.gnome.Documents';
+        } else {
+            GLib.set_prgname('gnome-books');
+            GLib.set_application_name(_("Books"));
+            appid = 'org.gnome.Books';
+        }
 
-        this.parent({ application_id: 'org.gnome.Documents',
+        this.parent({ application_id: appid,
                       inactivity_timeout: 12000 });
 
         this._searchProvider = new ShellSearchProvider.ShellSearchProvider();
@@ -187,12 +197,28 @@ const Application = new Lang.Class({
             }));
     },
 
+    _nightModeCreateHook: function(action) {
+        settings.connect('changed::night-mode', Lang.bind(this,
+            function() {
+                let state = settings.get_value('night-mode');
+                if (state.get_boolean()[0] != action.state.get_boolean()[0])
+                    action.state = state;
+
+                let gtkSettings = Gtk.Settings.get_default();
+                gtkSettings.gtk_application_prefer_dark_theme = state.get_boolean();
+            }));
+
+        let state = settings.get_value('night-mode');
+        let gtkSettings = Gtk.Settings.get_default();
+        gtkSettings.gtk_application_prefer_dark_theme = state.get_boolean();
+    },
+
     _onActionQuit: function() {
         this._mainWindow.window.destroy();
     },
 
     _onActionAbout: function() {
-        this._mainWindow.showAbout();
+        this._mainWindow.showAbout(this.isBooks);
     },
 
     _onActionHelp: function() {
@@ -205,6 +231,12 @@ const Application = new Lang.Class({
         }
     },
 
+    _onActionNightMode: function(action) {
+        let state = action.get_state();
+        action.change_state(GLib.Variant.new('b', !state.get_boolean()));
+        settings.set_value('night-mode', GLib.Variant.new('b', !state.get_boolean()));
+    },
+
     _onActionFullscreen: function() {
         modeController.toggleFullscreen();
     },
@@ -409,7 +441,10 @@ const Application = new Lang.Class({
         resource._register();
 
         application = this;
-        settings = new Gio.Settings({ schema_id: 'org.gnome.documents' });
+        if (!application.isBooks)
+            settings = new Gio.Settings({ schema: 'org.gnome.documents' });
+        else
+            settings = new Gio.Settings({ schema: 'org.gnome.books' });
 
         let gtkSettings = Gtk.Settings.get_default();
         gtkSettings.connect('notify::gtk-theme-name', Lang.bind(this, this._themeChanged));
@@ -431,11 +466,13 @@ const Application = new Lang.Class({
             return;
         }
 
-        try {
-            goaClient = Goa.Client.new_sync(null);
-        } catch (e) {
-            log('Unable to create the GOA client: ' + e.toString());
-            return;
+        if (!application.isBooks) {
+            try {
+                goaClient = Goa.Client.new_sync(null);
+            } catch (e) {
+                log('Unable to create the GOA client: ' + e.toString());
+                return;
+            }
         }
 
         connectionQueue = new TrackerController.TrackerConnectionQueue();
@@ -464,6 +501,10 @@ const Application = new Lang.Class({
               create_hook: this._fullscreenCreateHook,
               accel: 'F11',
               window_mode: WindowMode.WindowMode.PREVIEW },
+            { name: 'night-mode',
+              callback: this._onActionNightMode,
+              create_hook: this._nightModeCreateHook,
+              state: settings.get_value('night-mode') },
             { name: 'gear-menu',
               callback: this._onActionToggle,
               state: GLib.Variant.new('b', false),
@@ -542,7 +583,9 @@ const Application = new Lang.Class({
 
         this._initActions();
         this._initAppMenu();
-        this._initGettingStarted();
+
+        if (!this.isBooks)
+            this._initGettingStarted();
     },
 
     vfunc_shutdown: function() {
