@@ -232,6 +232,7 @@ const DocCommon = new Lang.Class({
         this.resourceUrn = null;
         this.surface = null;
         this.origPixbuf = null;
+        this.defaultApp = null;
         this.defaultAppName = null;
 
         this.mimeType = null;
@@ -585,8 +586,16 @@ const DocCommon = new Lang.Class({
     },
 
     open: function(screen, timestamp) {
+        if (!this.defaultAppName)
+            return;
+
+        // Without a defaultApp, launch in the web browser,
+        // otherwise use that system application
         try {
-            Gtk.show_uri(screen, this.uri, timestamp);
+            if (this.defaultApp)
+                this.defaultApp.launch_uris( [ this.uri ], null);
+            else
+                Gtk.show_uri(screen, this.uri, timestamp);
         } catch (e) {
             log('Unable to show URI ' + this.uri + ': ' + e.toString());
         }
@@ -657,12 +666,18 @@ const LocalDocument = new Lang.Class({
 
         this.sourceName = _("Local");
 
-        let defaultApp = null;
-        if (this.mimeType)
-            defaultApp = Gio.app_info_get_default_for_type(this.mimeType, true);
+        if (this.mimeType) {
+            let apps = Gio.app_info_get_recommended_for_type (this.mimeType);
+            for (let i = 0; i < apps.length; i++) {
+                if (apps[i].supports_uris ()) {
+                    this.defaultApp = apps[i];
+                    break;
+                }
+            }
+        }
 
-        if (defaultApp)
-            this.defaultAppName = defaultApp.get_name();
+        if (this.defaultApp)
+            this.defaultAppName = this.defaultApp.get_name();
     },
 
     populateFromCursor: function(cursor) {
@@ -879,6 +894,8 @@ const GoogleDocument = new Lang.Class({
             description = _("Spreadsheet");
         else if (this.rdfType.indexOf('nfo#Presentation') != -1)
             description = _("Presentation");
+        else if (this.rdfType.indexOf('nfo#EBook') != -1)
+            description = _("e-Book");
         else
             description = _("Document");
 
@@ -916,12 +933,11 @@ const OwncloudDocument = new Lang.Class({
         // overridden
         this.sourceName = _("ownCloud");
 
-        let defaultApp = null;
         if (this.mimeType)
-            defaultApp = Gio.app_info_get_default_for_type(this.mimeType, true);
+            this.defaultApp = Gio.app_info_get_default_for_type(this.mimeType, true);
 
-        if (defaultApp)
-            this.defaultAppName = defaultApp.get_name();
+        if (this.defaultApp)
+            this.defaultAppName = this.defaultApp.get_name();
     },
 
     createThumbnail: function(callback) {
@@ -1049,6 +1065,8 @@ const SkydriveDocument = new Lang.Class({
             description = _("Spreadsheet");
         else if (this.rdfType.indexOf('nfo#Presentation') != -1)
             description = _("Presentation");
+        else if (this.rdfType.indexOf('nfo#EBook') != -1)
+            description = _("e-Book");
         else
             description = _("Document");
 
