@@ -139,14 +139,17 @@ const EmptyResultsBox = new Lang.Class({
         this.widget.add(this._labelsGrid);
 
         let titleLabel = new Gtk.Label({ label: '<b><span size="large">' +
-                                         _("No Documents Found") +
+                                         (Application.application.isBooks ?
+                                          _("No Books Found") :
+                                          _("No Documents Found")) +
                                          '</span></b>',
                                          use_markup: true,
                                          halign: Gtk.Align.START,
                                          vexpand: true });
         this._labelsGrid.add(titleLabel);
 
-        if (Application.sourceManager.hasOnlineSources()) {
+        if (Application.sourceManager.hasOnlineSources() ||
+            Application.application.isBooks) {
             titleLabel.valign = Gtk.Align.CENTER;
         } else {
             titleLabel.valign = Gtk.Align.START;
@@ -281,9 +284,12 @@ const Embed = new Lang.Class({
     },
 
     _onActivateResult: function() {
-        let doc = this._view.getFirstDocument();
-        if (doc)
-            Application.documentManager.setActiveItem(doc)
+        let windowMode = Application.modeController.getWindowMode();
+
+        if (windowMode == WindowMode.WindowMode.OVERVIEW)
+            this._view.activateResult();
+        else if (windowMode == WindowMode.WindowMode.PREVIEW)
+            this._preview.activateResult();
     },
 
     _onQueryStatusChanged: function() {
@@ -399,7 +405,10 @@ const Embed = new Lang.Class({
     },
 
     _onLoadFinished: function(manager, doc, docModel) {
-        docModel.set_sizing_mode(EvView.SizingMode.AUTOMATIC);
+        if (!Application.application.isBooks)
+            docModel.set_sizing_mode(EvView.SizingMode.AUTOMATIC);
+        else
+            docModel.set_sizing_mode(EvView.SizingMode.FIT_PAGE);
         docModel.set_page_layout(EvView.PageLayout.AUTOMATIC);
         this._toolbar.setModel(docModel);
         this._preview.setModel(docModel);
