@@ -129,8 +129,12 @@ const MainWindow = new Lang.Class({
         let window = widget.get_window();
         let state = window.get_state();
 
-        if (state & Gdk.WindowState.FULLSCREEN)
+        if (state & Gdk.WindowState.FULLSCREEN) {
+            Application.modeController.setFullscreen(true);
             return;
+        }
+
+        Application.modeController.setFullscreen(false);
 
         let maximized = (state & Gdk.WindowState.MAXIMIZED);
         Application.settings.set_boolean('window-maximized', maximized);
@@ -291,21 +295,29 @@ const MainWindow = new Lang.Class({
         return false;
     },
 
-    showAbout: function() {
+    showAbout: function(isBooks) {
         let aboutDialog = new Gtk.AboutDialog();
 
         aboutDialog.artists = [ 'Jakub Steiner <jimmac@gmail.com>' ];
         aboutDialog.authors = [ 'Cosimo Cecchi <cosimoc@gnome.org>',
                                 'Florian M' + String.fromCharCode(0x00FC) + 'llner <fmuellner@gnome.org>',
-                                'William Jon McCann <william.jon.mccann@gmail.com>' ];
+                                'William Jon McCann <william.jon.mccann@gmail.com>',
+                                'Bastien Nocera <hadess@hadess.net>' ];
         aboutDialog.translator_credits = _("translator-credits");
-        aboutDialog.program_name = _("Documents");
-        aboutDialog.comments = _("A document manager application");
-        aboutDialog.copyright = 'Copyright ' + String.fromCharCode(0x00A9) + ' 2011' + String.fromCharCode(0x2013) + '2012 Red Hat, Inc.';
+        if (!isBooks) {
+            aboutDialog.program_name = _("Documents");
+            aboutDialog.comments = _("A document manager application");
+            aboutDialog.logo_icon_name = 'gnome-documents';
+            aboutDialog.website = 'https://wiki.gnome.org/Apps/Documents';
+        } else {
+            aboutDialog.program_name = _("Books");
+            aboutDialog.comments = _("An e-books manager application");
+            aboutDialog.logo_icon_name = 'gnome-books';
+            aboutDialog.website = 'https://wiki.gnome.org/Apps/Books';
+        }
+        aboutDialog.copyright = 'Copyright ' + String.fromCharCode(0x00A9) + ' 2011' + String.fromCharCode(0x2013) + '2014 Red Hat, Inc.';
         aboutDialog.license_type = Gtk.License.GPL_2_0;
-        aboutDialog.logo_icon_name = 'gnome-documents';
         aboutDialog.version = Config.PACKAGE_VERSION;
-        aboutDialog.website = 'https://wiki.gnome.org/Apps/Documents';
         aboutDialog.wrap_license = true;
 
         aboutDialog.modal = true;
