@@ -26,6 +26,7 @@ const Query = imports.query;
 const Lang = imports.lang;
 const Signals = imports.signals;
 
+const GdPrivate = imports.gi.GdPrivate;
 const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
 const Tracker = imports.gi.Tracker;
@@ -63,9 +64,9 @@ const SearchController = new Lang.Class({
     },
 
     getTerms: function() {
-        let escaped_str = Tracker.sparql_escape_string(this._string);
-        let str = GLib.utf8_casefold(escaped_str, -1);
-        return str.replace(/ +/g, ' ').split(' ');
+        let escapedStr = Tracker.sparql_escape_string(this._string);
+        let [tokens, ] = GLib.str_tokenize_and_fold(escapedStr, null);
+        return tokens;
     }
 });
 Signals.addSignalMethods(SearchController.prototype);
@@ -164,7 +165,9 @@ const SearchTypeStock = {
     PDF: 'pdf',
     PRESENTATIONS: 'presentations',
     SPREADSHEETS: 'spreadsheets',
-    TEXTDOCS: 'textdocs'
+    TEXTDOCS: 'textdocs',
+    EBOOKS: 'ebooks',
+    COMICS: 'comics'
 };
 
 const SearchTypeManager = new Lang.Class({
@@ -178,23 +181,45 @@ const SearchTypeManager = new Lang.Class({
 
         this.addItem(new SearchType({ id: SearchTypeStock.ALL,
                                       name: _("All") }));
-        this.addItem(new SearchType({ id: SearchTypeStock.COLLECTIONS,
-                                      name: _("Collections"),
-                                      filter: 'fn:starts-with(nao:identifier(?urn), \"gd:collection\")',
-                                      where: '?urn rdf:type nfo:DataContainer .' }));
-        this.addItem(new SearchType({ id: SearchTypeStock.PDF,
-                                      name: _("PDF Documents"),
-                                      filter: 'fn:contains(nie:mimeType(?urn), \"application/pdf\")',
-                                      where: '?urn rdf:type nfo:PaginatedTextDocument .' }));
-        this.addItem(new SearchType({ id: SearchTypeStock.PRESENTATIONS,
-                                      name: _("Presentations"),
-                                      where: '?urn rdf:type nfo:Presentation .' }));
-        this.addItem(new SearchType({ id: SearchTypeStock.SPREADSHEETS,
-                                      name: _("Spreadsheets"),
-                                      where: '?urn rdf:type nfo:Spreadsheet .' }));
-        this.addItem(new SearchType({ id: SearchTypeStock.TEXTDOCS,
-                                      name: _("Text Documents"),
-                                      where: '?urn rdf:type nfo:PaginatedTextDocument .' }));
+        if (!Application.application.isBooks) {
+            this.addItem(new SearchType({ id: SearchTypeStock.COLLECTIONS,
+                                          name: _("Collections"),
+                                          filter: 'fn:starts-with(nao:identifier(?urn), \"gd:collection\")',
+                                          where: '?urn rdf:type nfo:DataContainer .' }));
+            this.addItem(new SearchType({ id: SearchTypeStock.PDF,
+                                          name: _("PDF Documents"),
+                                          filter: 'fn:contains(nie:mimeType(?urn), \"application/pdf\")',
+                                          where: '?urn rdf:type nfo:PaginatedTextDocument .' }));
+        } else {
+            this.addItem(new SearchType({ id: SearchTypeStock.COLLECTIONS,
+                                          name: _("Collections"),
+                                          filter: 'fn:starts-with(nao:identifier(?urn), \"gb:collection\")',
+                                          where: '?urn rdf:type nfo:DataContainer .' }));
+            //FIXME we need to remove all the non-Comics PDFs here
+        }
+
+        if (!Application.application.isBooks) {
+            this.addItem(new SearchType({ id: SearchTypeStock.PRESENTATIONS,
+                                          name: _("Presentations"),
+                                          where: '?urn rdf:type nfo:Presentation .' }));
+            this.addItem(new SearchType({ id: SearchTypeStock.SPREADSHEETS,
+                                          name: _("Spreadsheets"),
+                                          where: '?urn rdf:type nfo:Spreadsheet .' }));
+            this.addItem(new SearchType({ id: SearchTypeStock.TEXTDOCS,
+                                          name: _("Text Documents"),
+                                          filter: 'NOT EXISTS { ?urn a nfo:EBook }',
+                                          where: '?urn rdf:type nfo:PaginatedTextDocument .' }));
+        } else {
+          this.addItem(new SearchType({ id: SearchTypeStock.EBOOKS,
+                                        name: _("e-Books"),
+                                        filter: '(nie:mimeType(?urn) IN (\"application/epub+zip\", \"application/x-mobipocket-ebook\", \"application/x-fictionbook+xml\", \"application/x-zip-compressed-fb2\"))',
+                                        where: '?urn rdf:type nfo:EBook .' }));
+          this.addItem(new SearchType({ id: SearchTypeStock.COMICS,
+                                        name: _("Comics"),
+                                        filter: '(nie:mimeType(?urn) IN (\"application/x-cbr\", \"application/x-cbz\", \"application/x-cbt\", \"application/x-cb7\"))',
+                                        where: '?urn rdf:type nfo:EBook .' }));
+        }
+
 
         this.setActiveItemById(SearchTypeStock.ALL);
     },
@@ -242,12 +267,22 @@ const SearchMatch = new Lang.Class({
     getFilter: function() {
         if (this.id == SearchMatchStock.TITLE)
             return ('fn:contains ' +
-                    '(tracker:case-fold(tracker:coalesce(nie:title(?urn), nfo:fileName(?urn))), ' +
-                    '"%s")').format(this._term);
+                    '(tracker:unaccent(tracker:case-fold' +
+                    '(tracker:coalesce(nie:title(?urn), nfo:fileName(?urn)))), ' +
+                    '"%s") || ' +
+                    'fn:contains ' +
+                    '(tracker:case-fold' +
+                    '(tracker:coalesce(nie:title(?urn), nfo:fileName(?urn))), ' +
+                    '"%s")').format(this._term, this._term);
         if (this.id == SearchMatchStock.AUTHOR)
             return ('fn:contains ' +
-                    '(tracker:case-fold(tracker:coalesce(nco:fullname(?creator), nco:fullname(?publisher))), ' +
-                    '"%s")').format(this._term);
+                    '(tracker:unaccent(tracker:case-fold' +
+                    '(tracker:coalesce(nco:fullname(?creator), nco:fullname(?publisher)))), ' +
+                    '"%s") || ' +
+                    'fn:contains ' +
+                    '(tracker:case-fold' +
+                    '(tracker:coalesce(nco:fullname(?creator), nco:fullname(?publisher))), ' +
+                    '"%s")').format(this._term, this._term);
         return '';
     }
 });
@@ -283,7 +318,7 @@ const SearchMatchManager = new Lang.Class({
             });
             filters.push(this.parent());
         }
-        return filters.length ? '( ' + filters.join(' && ') + ')' : '';
+        return filters.length ? '( ' + filters.join(' && ') + ')' : '(true)';
     }
 });
 
@@ -379,8 +414,10 @@ const Source = new Lang.Class({
                 filters.push('(fn:contains (nie:url(?urn), "%s"))'.format(location.get_uri()));
             }));
 
-        filters.push('(fn:starts-with (nao:identifier(?urn), "gd:collection:local:"))');
-
+        if (!Application.application.isBooks)
+            filters.push('(fn:starts-with (nao:identifier(?urn), "gd:collection:local:"))');
+        else
+            filters.push('(fn:starts-with (nao:identifier(?urn), "gb:collection:local:"))');
         return '(' + filters.join(' || ') + ')';
     },
 
@@ -428,11 +465,14 @@ const SourceManager = new Lang.Class({
                               builtin: true });
         this.addItem(source);
 
-        Application.goaClient.connect('account-added', Lang.bind(this, this._refreshGoaAccounts));
-        Application.goaClient.connect('account-changed', Lang.bind(this, this._refreshGoaAccounts));
-        Application.goaClient.connect('account-removed', Lang.bind(this, this._refreshGoaAccounts));
+        if (!Application.application.isBooks) {
+            Application.goaClient.connect('account-added', Lang.bind(this, this._refreshGoaAccounts));
+            Application.goaClient.connect('account-changed', Lang.bind(this, this._refreshGoaAccounts));
+            Application.goaClient.connect('account-removed', Lang.bind(this, this._refreshGoaAccounts));
+
+            this._refreshGoaAccounts();
+        }
 
-        this._refreshGoaAccounts();
         this.setActiveItemById(SearchSourceStock.ALL);
     },
 
