@@ -115,9 +115,7 @@ const ViewContainer = new Lang.Class({
     Name: 'ViewContainer',
 
     _init: function() {
-        this._adjustmentValueId = 0;
-        this._adjustmentChangedId = 0;
-        this._scrollbarVisibleId = 0;
+        this._edgeHitId = 0;
 
         this._model = new ViewModel();
 
@@ -177,7 +175,13 @@ const ViewContainer = new Lang.Class({
             this._addListRenderers();
     },
 
-    getFirstDocument: function() {
+    activateResult: function() {
+        let doc = this._getFirstDocument();
+        if (doc)
+            Application.documentManager.setActiveItem(doc)
+    },
+
+    _getFirstDocument: function() {
         let doc = null;
 
         let iter = this._model.model.get_iter_first()[1];
